@@ -178,8 +178,8 @@ class Node:
         else:
             return False
 
-    def add_foreign_account(self, key):
-        copyfile(key, "{}/keystore".format(self.datadir))
+    def add_foreign_account(self, key, name):
+        copyfile(key, "{}/keystore/{}".format(self.datadir, name))
 
     def get_first_account(self):
         """
